==> sogo-3.0.2.tar.gz: sogo-SOGo-3.0.2/README.md <==
## Contribute

SOGo is a collaborative effort in order to create the best Free and Open Source groupware solution.

There are multiple ways you can contribute to the project

* Documentation reviews, enhancements and translations
* Feature requests or by sharing your ideas (see the roadmap)
* Participate in the discussion on mailing lists
* Patches for bugs or enhancements
* Provide new translations

## Source Code

You can browse the lastest version of the source code online from Inverse's github repository:

* [https://github.com/inverse-inc](https://github.com/inverse-inc)

To compile SOGo, you first need to obtain the source code of both SOGo and SOPE. The source code of SOPE and SOGo can be obtained from Inverse's github repository:

* [https://github.com/inverse-inc/sope](https://github.com/inverse-inc/sope)
* [https://github.com/inverse-inc/sogo](https://github.com/inverse-inc/sogo)

The source code of the SOGo Connector and SOGo Integrator extensions for Thunderbird 31+ can be obtained from Inverse's github repository:

* [https://github.com/inverse-inc/sogo-connector.tb31](https://github.com/inverse-inc/sogo-connector.tb31)
* [https://github.com/inverse-inc/sogo-integrator.tb31](https://github.com/inverse-inc/sogo-integrator.tb31)

Please refer to the [FAQ](http://sogo.nu/support/faq.html) for [compilation instructions](http://sogo.nu/support/faq/article/how-do-i-compile-sogo-2.html).

## Translations

SOGo and its associated components are available in various languages. The following list describes the official translations alongside their maintainers :

* English - [Inverse inc.](http://www.inverse.ca/)
* Arabic - Anass Ahmed
* Basque - Gorka Gonzalez
* Brazilian Portuguese - Alexandre Marcilio
* Catalan - Hector M. Rulot Segovia
* Chinese (Taiwan)
* Croatian - Jens Riecken
* Czech - Šimon Halamásek
* Danish (Denmark) - Altibox
* Dutch - Roel van Os
* Finnish - Kari Salmu
* French - [Inverse](http://www.inverse.ca/)
* German - Alexander Greiner-Baer
* Hungarian - Sándor Kuti
* Icelandic - Anna Jonna Armannsdottir
* Italian - Alessio Fattorini
* Macedonian - Miroslav Jovanovic
* Norwegian (Bokmål) - Jan Ivar Karlsen
* Norwegian (Nynorsk) - Altibox
* Polish - Paweł Bogusławski
* Russian - Alex Kabakaev
* Slovak - Martin Pastor
* Slovenian - Jens Riecken
* Spanish (Argentina) - Federico Alberto Sayd
* Spanish (Spain) - Dominique Couot
* Swedish - Peter Johansson
* Ukrainian - Oleksa Stasevych
* Welsh - Iona Bailey
 
If you would like to translate the software in an other language, please consult the [FAQ](http://sogo.nu/support/faq/article/how-to-translate-sogo-in-another-language-2.html). You can also subscribe to the SOGo i18n mailing list to follow string additions or changes. To subscribe to i18n@sogo.nu, send an email to i18n-request@sogo.nu with SUBSCRIBE i18n as the subject. Archived posts are [available online](https://inverse.ca/sogo/lists/arc/i18n).

==> sogo-3.2.1.tar.gz: sogo-SOGo-3.2.1/README.md <==
## Contribute

SOGo is a collaborative effort in order to create the best Free and Open Source groupware solution.

There are multiple ways you can contribute to the project

* Documentation reviews, enhancements and translations
* Feature requests or by sharing your ideas (see the roadmap)
* Participate in the discussion on mailing lists
* Patches for bugs or enhancements
* Provide new translations

## Source Code

You can browse the lastest version of the source code online from Inverse's github repository:

* [https://github.com/inverse-inc](https://github.com/inverse-inc)

To compile SOGo, you first need to obtain the source code of both SOGo and SOPE. The source code of SOPE and SOGo can be obtained from Inverse's github repository:

* [https://github.com/inverse-inc/sope](https://github.com/inverse-inc/sope)
* [https://github.com/inverse-inc/sogo](https://github.com/inverse-inc/sogo)

The source code of the SOGo Connector and SOGo Integrator extensions for Thunderbird 31+ can be obtained from Inverse's github repository:

* [https://github.com/inverse-inc/sogo-connector.tb31](https://github.com/inverse-inc/sogo-connector.tb31)
* [https://github.com/inverse-inc/sogo-integrator.tb31](https://github.com/inverse-inc/sogo-integrator.tb31)

Please refer to the [FAQ](http://sogo.nu/support/faq.html) for [compilation instructions](http://sogo.nu/support/faq/article/how-do-i-compile-sogo-2.html).

## Translations

SOGo and its associated components are available in various languages. The following list describes the official translations alongside their maintainers :

* [en] English - [Inverse inc.](http://www.inverse.ca/)
* [ar] Arabic - Anass Ahmed
* [eu] Basque - Gorka Gonzalez
* [pr_BR] Brazilian Portuguese - Alexandre Marcilio
* [ca] Catalan - Hector M. Rulot Segovia
* [zh_TW] Chinese (Taiwan)
* [hr_HR] Croatian - Jens Riecken
* [cs] Czech - Šimon Halamásek
* [da_DK] Danish (Denmark) - Altibox
* [nl] Dutch - Roel van Os
* [fi] Finnish - Kari Salmu
* [fr] French - [Inverse](http://www.inverse.ca/)
* [de] German - Alexander Greiner-Baer
* [hu] Hungarian - Sándor Kuti
* [is] Icelandic - Anna Jonna Armannsdottir
* [it] Italian - Alessio Fattorini
* [lt] Lithuanian - Mantas Liobė
* [mk_MK] Macedonian - Miroslav Jovanovic
* [nb_NO] Norwegian (Bokmål) - Jan Ivar Karlsen
* [nn_NO] Norwegian (Nynorsk) - Altibox
* [pl] Polish - Paweł Bogusławski
* [pt] Portuguese - Eduardo Crispim
* [ru] Russian - Alex Kabakaev
* [sr] Serbian - Bogdanović Bojan
* [sk] Slovak - Martin Pastor
* [sl_SI] Slovenian - Jens Riecken
* [es_AR] Spanish (Argentina) - Federico Alberto Sayd
* [es_ES] Spanish (Spain) - Dominique Couot
* [sv] Swedish - Peter Johansson
* [tr_TR] Turkish (Turkey) - Sinan Kurşunoğlu
* [uk] Ukrainian - Oleksa Stasevych
* [cy] Welsh - Iona Bailey
 
If you would like to translate the software in an other language, please consult the [FAQ](http://sogo.nu/support/faq/article/how-to-translate-sogo-in-another-language-2.html). You can also subscribe to the SOGo i18n mailing list to follow string additions or changes. To subscribe to i18n@sogo.nu, send an email to i18n-request@sogo.nu with SUBSCRIBE i18n as the subject. Archived posts are [available online](https://inverse.ca/sogo/lists/arc/i18n).
